@@ -36,6 +36,7 @@ from .utils import (constrict_convex_hull_size,
                     to_convex_contour,
                     to_convex_hull,
                     to_polygon,
+                    to_star_contour,
                     to_strict_convex_hull)
 
 
@@ -704,9 +705,9 @@ def concave_contours(x_coordinates: Strategy[Coordinate],
     ...                                   allow_infinity=False,
     ...                                   allow_nan=False)
     >>> min_size, max_size = 5, 10
-    >>> contours = planar.contours(x_coordinates, y_coordinates,
-    ...                            min_size=min_size,
-    ...                            max_size=max_size)
+    >>> contours = planar.concave_contours(x_coordinates, y_coordinates,
+    ...                                    min_size=min_size,
+    ...                                    max_size=max_size)
     >>> contour = contours.example()
     >>> isinstance(contour, list)
     True
@@ -736,16 +737,19 @@ def concave_contours(x_coordinates: Strategy[Coordinate],
                                     else min(len(points), max_size))
         return strategies.tuples(strategies.just(points), sizes)
 
-    return (strategies.lists(points(x_coordinates, y_coordinates),
-                             min_size=min_size,
-                             max_size=max_size,
-                             unique=True)
-            .filter(points_do_not_lie_on_the_same_line)
-            .flatmap(to_points_with_sizes)
-            .map(pack(to_contour))
-            .filter(partial(_has_valid_size,
-                            min_size=min_size,
-                            max_size=max_size))
+    return ((star_contours(x_coordinates, y_coordinates,
+                           min_size=min_size,
+                           max_size=max_size)
+             | (strategies.lists(points(x_coordinates, y_coordinates),
+                                 min_size=min_size,
+                                 max_size=max_size,
+                                 unique=True)
+                .filter(points_do_not_lie_on_the_same_line)
+                .flatmap(to_points_with_sizes)
+                .map(pack(to_contour))
+                .filter(partial(_has_valid_size,
+                                min_size=min_size,
+                                max_size=max_size))))
             .filter(is_contour_non_convex))
 
 
@@ -1001,6 +1005,101 @@ def bounding_boxes(x_coordinates: Strategy[Coordinate],
                              .map(sort_pair))
 
 
+def star_contours(x_coordinates: Strategy[Coordinate],
+                  y_coordinates: Optional[Strategy[Coordinate]] = None,
+                  *,
+                  min_size: int = TRIANGULAR_CONTOUR_SIZE,
+                  max_size: Optional[int] = None) -> Strategy[Contour]:
+    """
+    Returns a strategy for star contours.
+    Star contour is a contour such that every vertex is visible from centroid,
+    i.e. segments from centroid to vertices do not cross or overlap contour.
+
+    :param x_coordinates: strategy for vertices' x-coordinates.
+    :param y_coordinates:
+        strategy for vertices' y-coordinates,
+        ``None`` for reusing x-coordinates strategy.
+    :param min_size: lower bound for contour size.
+    :param max_size: upper bound for contour size, ``None`` for unbound.
+
+    >>> from hypothesis import strategies
+    >>> from hypothesis_geometry import planar
+
+    For same coordinates' domain:
+
+    >>> min_coordinate, max_coordinate = -1., 1.
+    >>> coordinates_type = float
+    >>> coordinates = strategies.floats(min_coordinate, max_coordinate,
+    ...                                 allow_infinity=False,
+    ...                                 allow_nan=False)
+    >>> min_size, max_size = 5, 10
+    >>> contours = planar.star_contours(coordinates,
+    ...                                 min_size=min_size,
+    ...                                 max_size=max_size)
+    >>> contour = contours.example()
+    >>> isinstance(contour, list)
+    True
+    >>> min_size <= len(contour) <= max_size
+    True
+    >>> all(isinstance(vertex, tuple) for vertex in contour)
+    True
+    >>> all(len(vertex) == 2 for vertex in contour)
+    True
+    >>> all(isinstance(coordinate, coordinates_type)
+    ...     for vertex in contour
+    ...     for coordinate in vertex)
+    True
+    >>> all(min_coordinate <= coordinate <= max_coordinate
+    ...     for vertex in contour
+    ...     for coordinate in vertex)
+    True
+
+    For different coordinates' domains:
+
+    >>> min_x_coordinate, max_x_coordinate = -1., 1.
+    >>> min_y_coordinate, max_y_coordinate = 10., 100.
+    >>> coordinates_type = float
+    >>> x_coordinates = strategies.floats(min_x_coordinate, max_x_coordinate,
+    ...                                   allow_infinity=False,
+    ...                                   allow_nan=False)
+    >>> y_coordinates = strategies.floats(min_y_coordinate, max_y_coordinate,
+    ...                                   allow_infinity=False,
+    ...                                   allow_nan=False)
+    >>> min_size, max_size = 5, 10
+    >>> contours = planar.star_contours(x_coordinates, y_coordinates,
+    ...                                 min_size=min_size,
+    ...                                 max_size=max_size)
+    >>> contour = contours.example()
+    >>> isinstance(contour, list)
+    True
+    >>> min_size <= len(contour) <= max_size
+    True
+    >>> all(isinstance(vertex, tuple) for vertex in contour)
+    True
+    >>> all(len(vertex) == 2 for vertex in contour)
+    True
+    >>> all(isinstance(coordinate, coordinates_type)
+    ...     for vertex in contour
+    ...     for coordinate in vertex)
+    True
+    >>> all(min_x_coordinate <= vertex_x <= max_x_coordinate
+    ...     and min_y_coordinate <= vertex_y <= max_y_coordinate
+    ...     for vertex_x, vertex_y in contour)
+    True
+    """
+    _validate_sizes(min_size, max_size, TRIANGULAR_CONTOUR_SIZE)
+    min_size = max(min_size, TRIANGULAR_CONTOUR_SIZE)
+    return (strategies.lists(points(x_coordinates, y_coordinates),
+                             min_size=min_size,
+                             max_size=max_size,
+                             unique=True)
+            .filter(points_do_not_lie_on_the_same_line)
+            .map(to_star_contour)
+            .filter(partial(_has_valid_size,
+                            min_size=min_size,
+                            max_size=max_size)))
+
+
 EMPTY_MULTICONTOUR_SIZE = 0
 
 
