@@ -1,5 +1,9 @@
+import math
+from collections import deque
 from functools import partial
+from itertools import groupby
 from math import atan2
+from operator import itemgetter
 from random import Random
 from typing import (Callable,
                     Iterable,
@@ -17,7 +21,10 @@ from .core import triangular
 from .core.subdivisional import (QuadEdge,
                                  to_edge_neighbours)
 from .core.utils import (Orientation,
-                         orientation)
+                         contour_to_centroid,
+                         orientation,
+                         point_in_angle,
+                         points_to_centroid)
 from .hints import (Contour,
                     Coordinate,
                     Domain,
@@ -69,6 +76,38 @@ def to_contour(points: Sequence[Point], size: int) -> Contour:
     return result
 
 
+def to_star_contour(points: Sequence[Point]) -> Contour:
+    centroid = points_to_centroid(points)
+    result, prev_size = points, len(points) + 1
+    while 2 < len(result) < prev_size:
+        prev_size = len(result)
+        centroid_x, centroid_y = centroid
+        result = [deque(candidates,
+                        maxlen=1)[0][1]
+                  for _, candidates in groupby(sorted(
+                    (_to_segment_angle(centroid_x, centroid_y, point), point)
+                    for point in result),
+                    key=itemgetter(0))]
+        if len(result) > 2:
+            centroid = contour_to_centroid(result)
+            index = 0
+            while max(index, 2) < len(result):
+                if not point_in_angle(centroid,
+                                      result[index - 1],
+                                      result[index],
+                                      result[(index + 1) % len(result)]):
+                    del result[index]
+                index += 1
+            shrink_collinear_vertices(result)
+    return result
+
+
+def _to_segment_angle(start_x: Coordinate, start_y: Coordinate,
+                      end: Point) -> Coordinate:
+    end_x, end_y = end
+    return math.atan2(end_y - start_y, end_x - start_x)
+
+
 def to_polygon(points: Sequence[Point],
                size: int,
                holes_sizes: List[int]) -> Polygon:
